==> ViennaCL-1.6.2.tar.gz: ViennaCL-1.6.2/doc/html/error_8hpp.js <==
var error_8hpp =
[
    [ "device_not_found", "classviennacl_1_1ocl_1_1device__not__found.html", null ],
    [ "device_not_available", "classviennacl_1_1ocl_1_1device__not__available.html", null ],
    [ "compiler_not_available", "classviennacl_1_1ocl_1_1compiler__not__available.html", null ],
    [ "mem_object_allocation_failure", "classviennacl_1_1ocl_1_1mem__object__allocation__failure.html", null ],
    [ "out_of_resources", "classviennacl_1_1ocl_1_1out__of__resources.html", null ],
    [ "out_of_host_memory", "classviennacl_1_1ocl_1_1out__of__host__memory.html", null ],
    [ "profiling_info_not_available", "classviennacl_1_1ocl_1_1profiling__info__not__available.html", null ],
    [ "mem_copy_overlap", "classviennacl_1_1ocl_1_1mem__copy__overlap.html", null ],
    [ "image_format_mismatch", "classviennacl_1_1ocl_1_1image__format__mismatch.html", null ],
    [ "image_format_not_supported", "classviennacl_1_1ocl_1_1image__format__not__supported.html", null ],
    [ "build_program_failure", "classviennacl_1_1ocl_1_1build__program__failure.html", null ],
    [ "map_failure", "classviennacl_1_1ocl_1_1map__failure.html", null ],
    [ "invalid_value", "classviennacl_1_1ocl_1_1invalid__value.html", null ],
    [ "invalid_device_type", "classviennacl_1_1ocl_1_1invalid__device__type.html", null ],
    [ "invalid_platform", "classviennacl_1_1ocl_1_1invalid__platform.html", null ],
    [ "invalid_device", "classviennacl_1_1ocl_1_1invalid__device.html", null ],
    [ "invalid_context", "classviennacl_1_1ocl_1_1invalid__context.html", null ],
    [ "invalid_queue_properties", "classviennacl_1_1ocl_1_1invalid__queue__properties.html", null ],
    [ "invalid_command_queue", "classviennacl_1_1ocl_1_1invalid__command__queue.html", null ],
    [ "invalid_host_ptr", "classviennacl_1_1ocl_1_1invalid__host__ptr.html", null ],
    [ "invalid_mem_object", "classviennacl_1_1ocl_1_1invalid__mem__object.html", null ],
    [ "invalid_image_format_descriptor", "classviennacl_1_1ocl_1_1invalid__image__format__descriptor.html", null ],
    [ "invalid_image_size", "classviennacl_1_1ocl_1_1invalid__image__size.html", null ],
    [ "invalid_sampler", "classviennacl_1_1ocl_1_1invalid__sampler.html", null ],
    [ "invalid_binary", "classviennacl_1_1ocl_1_1invalid__binary.html", null ],
    [ "invalid_build_options", "classviennacl_1_1ocl_1_1invalid__build__options.html", null ],
    [ "invalid_program", "classviennacl_1_1ocl_1_1invalid__program.html", null ],
    [ "invalid_program_executable", "classviennacl_1_1ocl_1_1invalid__program__executable.html", null ],
    [ "invalid_kernel_name", "classviennacl_1_1ocl_1_1invalid__kernel__name.html", null ],
    [ "invalid_kernel_definition", "classviennacl_1_1ocl_1_1invalid__kernel__definition.html", null ],
    [ "invalid_kernel", "classviennacl_1_1ocl_1_1invalid__kernel.html", null ],
    [ "invalid_arg_index", "classviennacl_1_1ocl_1_1invalid__arg__index.html", null ],
    [ "invalid_arg_value", "classviennacl_1_1ocl_1_1invalid__arg__value.html", null ],
    [ "invalid_arg_size", "classviennacl_1_1ocl_1_1invalid__arg__size.html", null ],
    [ "invalid_kernel_args", "classviennacl_1_1ocl_1_1invalid__kernel__args.html", null ],
    [ "invalid_work_dimension", "classviennacl_1_1ocl_1_1invalid__work__dimension.html", null ],
    [ "invalid_work_group_size", "classviennacl_1_1ocl_1_1invalid__work__group__size.html", null ],
    [ "invalid_work_item_size", "classviennacl_1_1ocl_1_1invalid__work__item__size.html", null ],
    [ "invalid_global_offset", "classviennacl_1_1ocl_1_1invalid__global__offset.html", null ],
    [ "invalid_event_wait_list", "classviennacl_1_1ocl_1_1invalid__event__wait__list.html", null ],
    [ "invalid_event", "classviennacl_1_1ocl_1_1invalid__event.html", null ],
    [ "invalid_operation", "classviennacl_1_1ocl_1_1invalid__operation.html", null ],
    [ "invalid_gl_object", "classviennacl_1_1ocl_1_1invalid__gl__object.html", null ],
    [ "invalid_buffer_size", "classviennacl_1_1ocl_1_1invalid__buffer__size.html", null ],
    [ "invalid_mip_level", "classviennacl_1_1ocl_1_1invalid__mip__level.html", null ],
    [ "invalid_global_work_size", "classviennacl_1_1ocl_1_1invalid__global__work__size.html", null ],
    [ "invalid_property", "classviennacl_1_1ocl_1_1invalid__property.html", null ],
    [ "unknown_error", "classviennacl_1_1ocl_1_1unknown__error.html", null ],
    [ "double_precision_not_provided_error", "classviennacl_1_1ocl_1_1double__precision__not__provided__error.html", null ],
    [ "error_checker", "structviennacl_1_1ocl_1_1error__checker.html", null ],
    [ "VIENNACL_BUG_REPORT_STRING", "error_8hpp.html#a6d42757cdf0e944ebe5236aa4f96b6aa", null ],
    [ "VIENNACL_ERR_CHECK", "error_8hpp.html#a44f070f54255e72eb40c75ebd72ea602", null ]
];

==> ViennaCL-1.7.1.tar.gz: ViennaCL-1.7.1/doc/html/error_8hpp.js <==
var error_8hpp =
[
    [ "queue_not_found", "classviennacl_1_1ocl_1_1queue__not__found.html", "classviennacl_1_1ocl_1_1queue__not__found" ],
    [ "program_not_found", "classviennacl_1_1ocl_1_1program__not__found.html", "classviennacl_1_1ocl_1_1program__not__found" ],
    [ "kernel_not_found", "classviennacl_1_1ocl_1_1kernel__not__found.html", "classviennacl_1_1ocl_1_1kernel__not__found" ],
    [ "device_not_found", "classviennacl_1_1ocl_1_1device__not__found.html", null ],
    [ "device_not_available", "classviennacl_1_1ocl_1_1device__not__available.html", null ],
    [ "compiler_not_available", "classviennacl_1_1ocl_1_1compiler__not__available.html", null ],
    [ "mem_object_allocation_failure", "classviennacl_1_1ocl_1_1mem__object__allocation__failure.html", null ],
    [ "out_of_resources", "classviennacl_1_1ocl_1_1out__of__resources.html", null ],
    [ "out_of_host_memory", "classviennacl_1_1ocl_1_1out__of__host__memory.html", null ],
    [ "profiling_info_not_available", "classviennacl_1_1ocl_1_1profiling__info__not__available.html", null ],
    [ "mem_copy_overlap", "classviennacl_1_1ocl_1_1mem__copy__overlap.html", null ],
    [ "image_format_mismatch", "classviennacl_1_1ocl_1_1image__format__mismatch.html", null ],
    [ "image_format_not_supported", "classviennacl_1_1ocl_1_1image__format__not__supported.html", null ],
    [ "build_program_failure", "classviennacl_1_1ocl_1_1build__program__failure.html", null ],
    [ "map_failure", "classviennacl_1_1ocl_1_1map__failure.html", null ],
    [ "invalid_value", "classviennacl_1_1ocl_1_1invalid__value.html", null ],
    [ "invalid_device_type", "classviennacl_1_1ocl_1_1invalid__device__type.html", null ],
    [ "invalid_platform", "classviennacl_1_1ocl_1_1invalid__platform.html", null ],
    [ "invalid_device", "classviennacl_1_1ocl_1_1invalid__device.html", null ],
    [ "invalid_context", "classviennacl_1_1ocl_1_1invalid__context.html", null ],
    [ "invalid_queue_properties", "classviennacl_1_1ocl_1_1invalid__queue__properties.html", null ],
    [ "invalid_command_queue", "classviennacl_1_1ocl_1_1invalid__command__queue.html", null ],
    [ "invalid_host_ptr", "classviennacl_1_1ocl_1_1invalid__host__ptr.html", null ],
    [ "invalid_mem_object", "classviennacl_1_1ocl_1_1invalid__mem__object.html", null ],
    [ "invalid_image_format_descriptor", "classviennacl_1_1ocl_1_1invalid__image__format__descriptor.html", null ],
    [ "invalid_image_size", "classviennacl_1_1ocl_1_1invalid__image__size.html", null ],
    [ "invalid_sampler", "classviennacl_1_1ocl_1_1invalid__sampler.html", null ],
    [ "invalid_binary", "classviennacl_1_1ocl_1_1invalid__binary.html", null ],
    [ "invalid_build_options", "classviennacl_1_1ocl_1_1invalid__build__options.html", null ],
    [ "invalid_program", "classviennacl_1_1ocl_1_1invalid__program.html", null ],
    [ "invalid_program_executable", "classviennacl_1_1ocl_1_1invalid__program__executable.html", null ],
    [ "invalid_kernel_name", "classviennacl_1_1ocl_1_1invalid__kernel__name.html", null ],
    [ "invalid_kernel_definition", "classviennacl_1_1ocl_1_1invalid__kernel__definition.html", null ],
    [ "invalid_kernel", "classviennacl_1_1ocl_1_1invalid__kernel.html", null ],
    [ "invalid_arg_index", "classviennacl_1_1ocl_1_1invalid__arg__index.html", null ],
    [ "invalid_arg_value", "classviennacl_1_1ocl_1_1invalid__arg__value.html", null ],
    [ "invalid_arg_size", "classviennacl_1_1ocl_1_1invalid__arg__size.html", null ],
    [ "invalid_kernel_args", "classviennacl_1_1ocl_1_1invalid__kernel__args.html", null ],
    [ "invalid_work_dimension", "classviennacl_1_1ocl_1_1invalid__work__dimension.html", null ],
    [ "invalid_work_group_size", "classviennacl_1_1ocl_1_1invalid__work__group__size.html", null ],
    [ "invalid_work_item_size", "classviennacl_1_1ocl_1_1invalid__work__item__size.html", null ],
    [ "invalid_global_offset", "classviennacl_1_1ocl_1_1invalid__global__offset.html", null ],
    [ "invalid_event_wait_list", "classviennacl_1_1ocl_1_1invalid__event__wait__list.html", null ],
    [ "invalid_event", "classviennacl_1_1ocl_1_1invalid__event.html", null ],
    [ "invalid_operation", "classviennacl_1_1ocl_1_1invalid__operation.html", null ],
    [ "invalid_gl_object", "classviennacl_1_1ocl_1_1invalid__gl__object.html", null ],
    [ "invalid_buffer_size", "classviennacl_1_1ocl_1_1invalid__buffer__size.html", null ],
    [ "invalid_mip_level", "classviennacl_1_1ocl_1_1invalid__mip__level.html", null ],
    [ "invalid_global_work_size", "classviennacl_1_1ocl_1_1invalid__global__work__size.html", null ],
    [ "invalid_property", "classviennacl_1_1ocl_1_1invalid__property.html", null ],
    [ "unknown_error", "classviennacl_1_1ocl_1_1unknown__error.html", null ],
    [ "double_precision_not_provided_error", "classviennacl_1_1ocl_1_1double__precision__not__provided__error.html", null ],
    [ "error_checker", "structviennacl_1_1ocl_1_1error__checker.html", null ],
    [ "VIENNACL_BUG_REPORT_STRING", "error_8hpp.html#a6d42757cdf0e944ebe5236aa4f96b6aa", null ],
    [ "VIENNACL_ERR_CHECK", "error_8hpp.html#a44f070f54255e72eb40c75ebd72ea602", null ]
];
